@@ -97,6 +97,14 @@ msgstr "bar"
         po = polib.pofile('tests/test_obsolete_previousmsgid.po')
         self.assertTrue(isinstance(po, polib.POFile))
 
+    def test_pofile_and_mofile10(self):
+        """
+        Test mofile with a bytes object.
+        """
+        mo_bytes = b"\xde\x12\x04\x95\x00\x00\x00\x00\x05\x00\x00\x00\x1c\x00\x00\x00D\x00\x00\x00\x07\x00\x00\x00l\x00\x00\x00\x00\x00\x00\x00\x88\x00\x00\x00\x10\x00\x00\x00\x89\x00\x00\x00\x07\x00\x00\x00\x9a\x00\x00\x00\x0c\x00\x00\x00\xa2\x00\x00\x00\x0b\x00\x00\x00\xaf\x00\x00\x00(\x00\x00\x00\xbb\x00\x00\x00\n\x00\x00\x00\xe4\x00\x00\x00\x10\x00\x00\x00\xef\x00\x00\x00\x0f\x00\x00\x00\x00\x01\x00\x00\x16\x00\x00\x00\x10\x01\x00\x00\x01\x00\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00SNAR_BEZEICHNUNG\x00conform\x00inconclusive\x00non-conform\x00Content-Type: text/plain; charset=UTF-8\n\x00Feldfrucht\x00\xc3\x9cbereinstimmung\x00Nicht eindeutig\x00Keine \xc3\x9cbereinstimmung\x00"
+        mo = polib.mofile(mo_bytes)
+        self.assertTrue(isinstance(mo, polib.MOFile))
+
     def test_ufeff_data_pofile(self):
         """
         Test that an ufeff prefixed pofile returns a POFile instance.
@@ -141,6 +149,23 @@ msgstr "bar"
             expected
         )
 
+    def test_previous_msgid_3(self):
+        """
+        Test saving empty previous msgid.
+        """
+        po = polib.pofile('tests/test_previous_msgid.po')
+        fd, tmpfile = tempfile.mkstemp()
+        os.close(fd)
+        po.save(tmpfile)
+        po = polib.pofile(tmpfile)
+        os.remove(tmpfile)
+
+        expected = ""
+        self.assertEqual(
+            po[2].previous_msgid,
+            expected
+        )
+
     def test_previous_msgctxt_1(self):
         """
         Test previous msgctxt multiline.
@@ -229,6 +254,18 @@ msgstr ""
             msg = 'Syntax error in po file (line 4): unescaped double quote found'
             self.assertEqual(str(exc), msg)
 
+    def test_syntax_error1(self):
+        """
+        Test that syntax error is raised while processing a symbol parsing.
+        """
+        try:
+            polib.pofile('tests/test_syntax_error1.po')
+            self.fail("Syntax error not detected")
+        except IOError:
+            exc = sys.exc_info()[1]
+            msg = "Syntax error in po file tests/test_syntax_error1.po (line 5)"
+            self.assertEqual(str(exc), msg)
+
     def test_detect_encoding1(self):
         """
         Test that given encoding is returned when file has no encoding defined.
@@ -285,8 +322,8 @@ msgstr ""
         Tests the escape function.
         """
         self.assertEqual(
-            polib.escape('\\t and \\n and \\r and " and \\ and \\\\'),
-            '\\\\t and \\\\n and \\\\r and \\" and \\\\ and \\\\\\\\'
+            polib.escape('\\t and \\n and \\r and " and \\ and \\\\ and \\v and \\b and \\f'),
+            '\\\\t and \\\\n and \\\\r and \\" and \\\\ and \\\\\\\\ and \\\\v and \\\\b and \\\\f'
         )
 
     def test_unescape(self):
@@ -294,8 +331,8 @@ msgstr ""
         Tests the unescape function.
         """
         self.assertEqual(
-            polib.unescape('\\\\t and \\\\n and \\\\r and \\\\" and \\\\\\\\'),
-            '\\t and \\n and \\r and \\" and \\\\'
+            polib.unescape('\\t and \\n and \\r and \\" and \\\\ and \\v and \\b and \\f'),
+            '\t and \n and \r and \" and \\ and \v and \b and \f'
         )
 
     def test_pofile_with_subclass(self):
@@ -560,6 +597,22 @@ msgstr ""
 msgid ""
 msgstr "Content-Type: text/plain; charset=UTF-8\n"
 
+msgid "foo"
+msgstr "oof"
+'''
+        self.assertEqual(str(pofile), expected)
+
+    def test_comment_ordering(self):
+        """
+        Test that "# " comments appear before "#. " comments when writing.
+        """
+        pofile  = polib.pofile('tests/test_comment_ordering.po')
+        expected = r'''#
+msgid ""
+msgstr "Content-Type: text/plain; charset=UTF-8\n"
+
+# First comment line
+#. Second comment line
 msgid "foo"
 msgstr "oof"
 '''
@@ -662,7 +715,7 @@ class TestPoFile(unittest.TestCase):
             msgid_plural="Plural", msgid="foo"
         )
         other = polib.POEntry(
-            msgid_plural="Plural", msgstr_plural="Pluriel", msgid="foo"
+            msgid_plural="Plural", msgstr_plural={0: "Value", 1: "Values"}, msgid="foo"
         )
         self.assertNotEqual(entry, other)
 
@@ -677,8 +730,8 @@ class TestPoFile(unittest.TestCase):
         self.assertNotEqual(entry, other)
 
     def test_compare6(self):
-        entry = polib.POEntry(msgstr_plural="Some plural", msgid="foo")
-        other = polib.POEntry(msgstr_plural="Other plural", msgid="foo")
+        entry = polib.POEntry(msgstr_plural={0: "Value", 1: "Values"}, msgid="foo")
+        other = polib.POEntry(msgstr_plural={0: "Other value", 1: "Other values"}, msgid="foo")
         self.assertTrue(entry > other)
 
     def test_compare7(self):
@@ -694,14 +747,24 @@ class TestPoFile(unittest.TestCase):
     def test_compare8(self):
         entry = polib.POEntry(
             msgctxt="Some context", msgid_plural="Plural",
-            msgstr_plural="Pluriel", msgid="foo"
+            msgstr_plural={0: "Value", 1: "Values"}, msgid="foo"
         )
         other = polib.POEntry(
             msgctxt="Some context", msgid_plural="Plural",
-            msgstr_plural="Pluriel", msgid="foo"
+            msgstr_plural={0: "Value", 1: "Values"}, msgid="foo"
         )
         self.assertEqual(entry, other)
 
+    def test_fuzzy_obsolete(self):
+        pofile = polib.pofile('tests/test_obsolete_is_not_fuzzy.po')
+        self.assertEqual(len(pofile.fuzzy_entries()), 1)
+
+    def test_set_fuzzy(self):
+        pofile = polib.pofile('tests/test_set_fuzzy.po')
+        pofile[0].fuzzy = True
+        pofile[1].fuzzy = False
+        self.assertTrue(pofile[0].fuzzy)
+        self.assertFalse(pofile[1].fuzzy)
 
 class TestMoFile(unittest.TestCase):
     """
